import serial
import sys

class UART:

  def __init__(self, ch, baud):
    try:
      self.ser = serial.Serial()
      self.ser.port = ch
      self.ser.baudrate = baud
    except:
      print("Input Ivalid, Please Check again!")
      sys.exit()
  
  def open(self):
    try:
      self.ser.open()
      print("UART open success!")
    except:
      print("Check your Port!")
      sys.exit()
    
  def available(self):
    ret = self.ser.in_waiting
    return ret
  
  def read(self):
    return self.ser.read(size=1)
  
  def write(self, data):
    ret =  self.ser.write(data)
    self.ser.flush()
    return ret
  
  def close(self):
    return self.ser.close()


from setuptools import setup, find_packages
import codecs
import os

here = os.path.abspath(os.path.dirname(__file__))

with codecs.open(os.path.join(here, "README.md"), encoding="utf-8") as fh:
    long_description = "\n" + fh.read()

VERSION = '0.0.11'
DESCRIPTION = 'STM32 CLI'
LONG_DESCRIPTION = 'A package that allows comunicate STM32'

# Setting up
setup(
    name="stm32cli",
    version=VERSION,
    author="loye (PHUC LOI)",
    author_email="phucloi97@hotmail.com",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=long_description,
    packages=find_packages(),
    install_requires=['pyserial', 'colorama', 'click'],
    keywords=["stm32", "cli", "bootloader"],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ],
    entry_points={
      "console_scripts":[
        "stm32cli=stm32cli:main",
        ],
    },

)